@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2021 Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2021-2023 Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -19,10 +19,10 @@ prefix="/usr"
 
 # Include utilities. Use installed version if available and
 # use build version if it isn't.
-if [ -e ${prefix}/share/kea/scripts/admin-utils.sh ]; then
+if test -f "${prefix}/share/kea/scripts/admin-utils.sh"; then
     . "${prefix}/share/kea/scripts/admin-utils.sh"
 else
-    . "/build/kea/src/kea-2.0.3/src/bin/admin/admin-utils.sh"
+    . "/build/kea/src/kea-2.4.0/src/bin/admin/admin-utils.sh"
 fi
 
 # Check version.
@@ -37,7 +37,7 @@ fi
 # query information_schema for the right database.
 for arg in "${@}"
 do
-    if ! printf '%s' "${arg}" | grep -Eq '^\-\-'
+    if ! printf '%s' "${arg}" | grep -Eq -- '^--'
     then
         schema="$arg"
         break
@@ -52,6 +52,7 @@ then
 fi
 
 mysql "$@" <<EOF
+-- This line starts the schema upgrade to version 11.0.
 
 -- Reverse index order to improve reclamation query performance
 -- Add a constraint that any state value added to the lease4 must
@@ -77,9 +78,10 @@ ALTER TABLE dhcp6_client_class
     ADD COLUMN min_preferred_lifetime INT(10) DEFAULT NULL,
     ADD COLUMN max_preferred_lifetime INT(10) DEFAULT NULL;
 
--- Update the schema version number
+-- Update the schema version number.
 UPDATE schema_version
     SET version = '11', minor = '0';
 
--- This line concludes database upgrade to version 11.0
+-- This line concludes the schema upgrade to version 11.0
+
 EOF
