@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2019-2021 Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2019-2023 Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -25,13 +25,18 @@ prefix="/usr"
 
 # Include utilities. Use installed version if available and
 # use build version if it isn't.
-if [ -e ${prefix}/share/kea/scripts/admin-utils.sh ]; then
+if test -f "${prefix}/share/kea/scripts/admin-utils.sh"; then
     . "${prefix}/share/kea/scripts/admin-utils.sh"
 else
-    . "/build/kea/src/kea-2.0.2/src/bin/admin/admin-utils.sh"
+    . "/build/kea/src/kea-2.4.0/src/bin/admin/admin-utils.sh"
 fi
 
-# First argument is must be the expected schema version <major>.<minor>
+# First argument must be the expected schema version <major>.<minor>
+# Check if it's passed at all.
+if [ "$#" -lt "1" ]; then
+    printf "Required at least one parameter: schema version number, e.g. 7.0\n"
+    exit 1
+fi
 exp_version="$1"
 shift
 
@@ -104,8 +109,14 @@ DELETE FROM hosts;
 DELETE FROM ipv6_reservations;
 DELETE FROM lease4;
 DELETE FROM lease4_stat;
+DELETE FROM lease4_pool_stat;
 DELETE FROM lease6;
 DELETE FROM lease6_stat;
+DELETE FROM lease6_pool_stat;
 DELETE FROM logs;
+DELETE FROM lease4_stat_by_client_class;
+DELETE FROM lease6_stat_by_client_class;
+DELETE FROM lease6_relay_id;
+DELETE FROM lease6_remote_id;
 COMMIT;
 EOF
